[tip:x86/asm] x86/entry/64: Make gs_change a local label

2016-04-13 Thread tip-bot for Borislav Petkov
Commit-ID:  42c748bb2544f21c3d115240527fe4478e193641
Gitweb: http://git.kernel.org/tip/42c748bb2544f21c3d115240527fe4478e193641
Author: Borislav Petkov 
AuthorDate: Thu, 7 Apr 2016 17:31:50 -0700
Committer:  Ingo Molnar 
CommitDate: Wed, 13 Apr 2016 10:20:42 +0200

x86/entry/64: Make gs_change a local label

... so that it doesn't appear in objdump output.

Signed-off-by: Borislav Petkov 
Signed-off-by: Andy Lutomirski 
Cc: Andy Lutomirski 
Cc: Borislav Petkov 
Cc: Brian Gerst 
Cc: Denys Vlasenko 
Cc: H. Peter Anvin 
Cc: Linus Torvalds 
Cc: Peter Zijlstra 
Cc: Rudolf Marek 
Cc: Thomas Gleixner 
Link: 
http://lkml.kernel.org/r/b9c532a0e5f8d56dede2bd59767d40024d5a75e2.1460075211.git.l...@kernel.org
Signed-off-by: Ingo Molnar 
---
 arch/x86/entry/entry_64.S | 10 +-
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/arch/x86/entry/entry_64.S b/arch/x86/entry/entry_64.S
index 64d2033..1693c17 100644
--- a/arch/x86/entry/entry_64.S
+++ b/arch/x86/entry/entry_64.S
@@ -781,7 +781,7 @@ ENTRY(native_load_gs_index)
pushfq
DISABLE_INTERRUPTS(CLBR_ANY & ~CLBR_RDI)
SWAPGS
-gs_change:
+.Lgs_change:
movl%edi, %gs
 2: ALTERNATIVE "", "mfence", X86_BUG_SWAPGS_FENCE
SWAPGS
@@ -789,7 +789,7 @@ gs_change:
ret
 END(native_load_gs_index)
 
-   _ASM_EXTABLE(gs_change, bad_gs)
+   _ASM_EXTABLE(.Lgs_change, bad_gs)
.section .fixup, "ax"
/* running with kernelgs */
 bad_gs:
@@ -1019,13 +1019,13 @@ ENTRY(error_entry)
movl%ecx, %eax  /* zero extend */
cmpq%rax, RIP+8(%rsp)
je  .Lbstep_iret
-   cmpq$gs_change, RIP+8(%rsp)
+   cmpq$.Lgs_change, RIP+8(%rsp)
jne .Lerror_entry_done
 
/*
 * hack: gs_change can fail with user gsbase.  If this happens, fix up
 * gsbase and proceed.  We'll fix up the exception and land in
 * gs_change's error handler with kernel gsbase.
 */
jmp .Lerror_entry_from_usermode_swapgs
 


[tip:x86/asm] x86/entry/64: Make gs_change a local label

2016-04-13 Thread tip-bot for Borislav Petkov
Commit-ID:  42c748bb2544f21c3d115240527fe4478e193641
Gitweb: http://git.kernel.org/tip/42c748bb2544f21c3d115240527fe4478e193641
Author: Borislav Petkov 
AuthorDate: Thu, 7 Apr 2016 17:31:50 -0700
Committer:  Ingo Molnar 
CommitDate: Wed, 13 Apr 2016 10:20:42 +0200

x86/entry/64: Make gs_change a local label

... so that it doesn't appear in objdump output.

Signed-off-by: Borislav Petkov 
Signed-off-by: Andy Lutomirski 
Cc: Andy Lutomirski 
Cc: Borislav Petkov 
Cc: Brian Gerst 
Cc: Denys Vlasenko 
Cc: H. Peter Anvin 
Cc: Linus Torvalds 
Cc: Peter Zijlstra 
Cc: Rudolf Marek 
Cc: Thomas Gleixner 
Link: 
http://lkml.kernel.org/r/b9c532a0e5f8d56dede2bd59767d40024d5a75e2.1460075211.git.l...@kernel.org
Signed-off-by: Ingo Molnar 
---
 arch/x86/entry/entry_64.S | 10 +-
 1 file changed, 5 insertions(+), 5 deletions(-)
@@ -1019,13 +1019,13 @@ ENTRY(error_entry)
 
/*
-* hack: gs_change can fail with user gsbase.  If this happens, fix up
+* hack: .Lgs_change can fail with user gsbase.  If this happens, fix up
 * gsbase and proceed.  We'll fix up the exception and land in
@@ -1019,13 +1019,13 @@ ENTRY(error_entry)
 * gsbase and proceed.  We'll fix up the exception and land in
-* gs_change's error handler with kernel gsbase.
+* .Lgs_change's error handler with kernel gsbase.
 */
jmp .Lerror_entry_from_usermode_swapgs

diff --git a/arch/x86/entry/entry_64.S b/arch/x86/entry/entry_64.S
index 64d2033..1693c17 100644
--- a/arch/x86/entry/entry_64.S
+++ b/arch/x86/entry/entry_64.S
@@ -781,7 +781,7 @@ ENTRY(native_load_gs_index)
pushfq
DISABLE_INTERRUPTS(CLBR_ANY & ~CLBR_RDI)
SWAPGS
-gs_change:
+.Lgs_change:
movl%edi, %gs
 2: ALTERNATIVE "", "mfence", X86_BUG_SWAPGS_FENCE
SWAPGS
@@ -789,7 +789,7 @@ gs_change:
ret
 END(native_load_gs_index)
 
-   _ASM_EXTABLE(gs_change, bad_gs)
+   _ASM_EXTABLE(.Lgs_change, bad_gs)
.section .fixup, "ax"
/* running with kernelgs */
 bad_gs:
@@ -1019,13 +1019,13 @@ ENTRY(error_entry)
movl%ecx, %eax  /* zero extend */
cmpq%rax, RIP+8(%rsp)
je  .Lbstep_iret
-   cmpq$gs_change, RIP+8(%rsp)
+   cmpq$.Lgs_change, RIP+8(%rsp)
jne .Lerror_entry_done
 
/*
 * hack: gs_change can fail with user gsbase.  If this happens, fix up
 * gsbase and proceed.  We'll fix up the exception and land in
 * gs_change's error handler with kernel gsbase.
 */
@@ -1019,13 +1019,13 @@ ENTRY(error_entry)
 
/*
-* hack: gs_change can fail with user gsbase.  If this happens, fix up
+* hack: .Lgs_change can fail with user gsbase.  If this happens, fix up
 * gsbase and proceed.  We'll fix up the exception and land in
@@ -1019,13 +1019,13 @@ ENTRY(error_entry)
 * gsbase and proceed.  We'll fix up the exception and land in
-* gs_change's error handler with kernel gsbase.
+* .Lgs_change's error handler with kernel gsbase.
 */
jmp .Lerror_entry_from_usermode_swapgs
jmp .Lerror_entry_from_usermode_swapgs